#[non_exhaustive]pub struct ToDeviceStreamUpdateEventContent {
pub room_id: OwnedRoomId,
pub event_id: OwnedEventId,
pub seq: UInt,
pub operation: StreamUpdateOperation,
}Available on crate features
events and unstable-msc4471 only.Expand description
The content of a to-device m.stream.update event.
Sent by the publisher device to a subscriber device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.room_id: OwnedRoomIdThe room containing the stream descriptor.
event_id: OwnedEventIdThe event containing the stream descriptor.
seq: UIntA monotonically increasing sequence number for this subscriber device’s view of the stream.
Clients should ignore updates whose seq is less than or equal to the
latest sequence number already applied for this stream.
operation: StreamUpdateOperationThe update operation.
Implementations
Sourceimpl ToDeviceStreamUpdateEventContent
impl ToDeviceStreamUpdateEventContent
Sourcepub fn new(
room_id: OwnedRoomId,
event_id: OwnedEventId,
seq: UInt,
operation: StreamUpdateOperation,
) -> ToDeviceStreamUpdateEventContent
pub fn new( room_id: OwnedRoomId, event_id: OwnedEventId, seq: UInt, operation: StreamUpdateOperation, ) -> ToDeviceStreamUpdateEventContent
Creates a new ToDeviceStreamUpdateEventContent with the given room,
event, sequence number, and operation.